%bcond_without check

Name:           rust2rpm
Version:        27.0.1
Release:        %mkrel 5
Summary:        Generate RPM spec files for Rust crates
License:        MIT
Group:          System/Packaging
URL:            https://pagure.io/fedora-rust/rust2rpm
Source:         %{url}/archive/v%{version}/rust2rpm-%{version}.tar.gz
# Upstreamed Mageia patches
# https://pagure.io/fedora-rust/rust2rpm/pull-request/304
Patch101:       0001-Update-Mageia-support-to-match-current-Mageia-Cauldr.patch
Patch102:       0002-Update-Mageia-related-test-.spec-files.patch
# Mageia patches
Patch103:       0001-Test-only-Fedora-and-Mageia-generators-as-we-lack-bo.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  asciidoctor

%if %{with check}
BuildRequires:  cargo
BuildRequires:  rust2rpm-helper >= 0.1.2
%endif

Requires:       cargo
Requires:       cargo-rpm-macros
Recommends:     rust2rpm-helper >= 0.1.2

# obsolete old provides (removed in Fedora 38)
Obsoletes:      cargo-inspector < 24

# obsolete and / or provide removed Python subpackages (removed in Fedora 38)
%py_provides    python3-rust2rpm
Obsoletes:      python3-rust2rpm < 24
Obsoletes:      python3-rust2rpm-core < 24

%description
rust2rpm is a tool that automates the generation of RPM spec files for
Rust crates.

%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires %{?with_check:-t}

%build
%pyproject_wheel
# build man pages
pushd docs
asciidoctor -b manpage rust2rpm.1.asciidoc
asciidoctor -b manpage rust2rpm.conf.5.asciidoc
asciidoctor -b manpage rust2rpm.toml.5.asciidoc
popd

%install
%pyproject_install
%pyproject_save_files rust2rpm
# install man pages
install -Dpm 644 docs/rust2rpm.1 -t %{buildroot}/%{_mandir}/man1/
install -Dpm 644 docs/rust2rpm.conf.5 -t %{buildroot}/%{_mandir}/man5/
install -Dpm 644 docs/rust2rpm.toml.5 -t %{buildroot}/%{_mandir}/man5/

%check
%pyproject_check_import
%if %{with check}
%tox
%endif

%files -f %{pyproject_files}
%doc README.md
%doc CHANGELOG.md
%{_bindir}/rust2rpm
%{_mandir}/man1/rust2rpm.1*
%{_mandir}/man5/rust2rpm.{conf,toml}.5*


%changelog
* Sun Apr 27 2025 wally <wally> 27.0.1-5.mga10
+ Revision: 2179175
- remove 'drop %%bcond()' patches as our BS supports %%bcond() nowadays

* Mon Feb 24 2025 wally <wally> 27.0.1-4.mga10
+ Revision: 2151813
- rebuild for python3.13

* Tue Dec 31 2024 wally <wally> 27.0.1-3.mga10
+ Revision: 2132142
- update Mageia patches to work with new Development/Rust RPM group

* Mon Dec 30 2024 wally <wally> 27.0.1-2.mga10
+ Revision: 2132065
- use %%bcond_with(out) for checks

* Mon Dec 30 2024 wally <wally> 27.0.1-1.mga10
+ Revision: 2132060
- new version 27.0.1

* Sun Sep 22 2024 wally <wally> 26.1.1-1.mga10
+ Revision: 2100206
- new version 26.1.1
- add patches to create .specs more close to Fedora
- test only Mageia and Fedora .spec generators

* Sun Jan 07 2024 wally <wally> 25.0.4-1.mga10
+ Revision: 2028616
- add RPM group
- mageiafy .spec
- imported package rust2rpm


* Fri Dec 08 2023 Fabio Valentini <decathorpe@gmail.com> - 25.0.4-1
- Update to version 25.0.4; Fixes RHBZ#2253476

* Fri Dec 01 2023 Fabio Valentini <decathorpe@gmail.com> - 25.0.3-1
- Update to version 25.0.3; Fixes RHBZ#2252419

* Sun Nov 19 2023 Fabio Valentini <decathorpe@gmail.com> - 25.0.2-1
- Update to version 25.0.2; Fixes RHBZ#2250386

* Wed Oct 18 2023 Fabio Valentini <decathorpe@gmail.com> - 25.0.1-1
- Update to version 25.0.1; Fixes RHBZ#2244803

* Tue Oct 10 2023 Fabio Valentini <decathorpe@gmail.com> - 25.0.0-1
- Update to version 25.0.0; Fixes RHBZ#2242982

* Sat Sep 30 2023 Fabio Valentini <decathorpe@gmail.com> - 24.4.2-1
- Update to version 24.4.2; Fixes RHBZ#2241494

* Thu Aug 10 2023 Fabio Valentini <decathorpe@gmail.com> - 24.4.0-1
- Update to version 24.4.0; Fixes RHBZ#2230003

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 24.3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jun 14 2023 Python Maint <python-maint@redhat.com> - 24.3.3-2
- Rebuilt for Python 3.12

* Wed May 17 2023 Fabio Valentini <decathorpe@gmail.com> - 24.3.3-1
- Update to version 24.3.3; Fixes RHBZ#2208046

* Wed Apr 19 2023 Fabio Valentini <decathorpe@gmail.com> - 24.3.1-1
- Update to version 24.3.1; Fixes RHBZ#2188097

* Sun Apr 02 2023 Fabio Valentini <decathorpe@gmail.com> - 24.3.0-1
- Update to version 24.3.0; Fixes RHBZ#2183736

* Tue Mar 21 2023 Fabio Valentini <decathorpe@gmail.com> - 24.2.0-1
- Update to version 24.2.0; Fixes RHBZ#2180212

* Mon Mar 06 2023 Fabio Valentini <decathorpe@gmail.com> - 24.1.0-1
- Update to version 24.1.0; Fixes RHBZ#2175278

* Thu Feb 16 2023 Fabio Valentini <decathorpe@gmail.com> - 24.0.2-1
- Update to version 24.0.2

* Thu Feb 16 2023 Fabio Valentini <decathorpe@gmail.com> - 24.0.1-1
- Update to version 24.0.1

* Thu Feb 16 2023 Fabio Valentini <decathorpe@gmail.com> - 24.0.0-1
- Initial import (#2170204)
